From: Richard Genoud <richard.genoud@bootlin.com>
To: Miquel Raynal <miquel.raynal@bootlin.com>,
Richard Weinberger <richard@nod.at>,
Vignesh Raghavendra <vigneshr@ti.com>,
Chen-Yu Tsai <wens@csie.org>,
Jernej Skrabec <jernej.skrabec@gmail.com>,
Samuel Holland <samuel@sholland.org>
Cc: Wentao Liang <vulab@iscas.ac.cn>,
Maxime Ripard <mripard@kernel.org>,
Boris Brezillon <bbrezillon@kernel.org>,
Thomas Petazzoni <thomas.petazzoni@bootlin.com>,
linux-mtd@lists.infradead.org,
linux-arm-kernel@lists.infradead.org,
linux-sunxi@lists.linux.dev, linux-kernel@vger.kernel.org,
Richard Genoud <richard.genoud@bootlin.com>
Subject: [PATCH v3 1/9] mtd: rawnand: sunxi: sunxi_nand_ooblayout_free code clarification
Date: Tue, 17 Mar 2026 15:24:29 +0100 [thread overview]
Message-ID: <20260317142437.580204-2-richard.genoud@bootlin.com> (raw)
In-Reply-To: <20260317142437.580204-1-richard.genoud@bootlin.com>
The available length is really USER_DATA_LEN - 2 instead of just 2 (the
user data length minus the BBM length)
USER_DATA_LEN being 4, that doesn't change anything now, but if
USER_DATA_LEN changes, it will.
Signed-off-by: Richard Genoud <richard.genoud@bootlin.com>
---
drivers/mtd/nand/raw/sunxi_nand.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/drivers/mtd/nand/raw/sunxi_nand.c b/drivers/mtd/nand/raw/sunxi_nand.c
index e66adfcca7cd..915f1240546f 100644
--- a/drivers/mtd/nand/raw/sunxi_nand.c
+++ b/drivers/mtd/nand/raw/sunxi_nand.c
@@ -1755,12 +1755,12 @@ static int sunxi_nand_ooblayout_free(struct mtd_info *mtd, int section,
/*
* The first 2 bytes are used for BB markers, hence we
* only have 2 bytes available in the first user data
* section.
*/
if (!section && ecc->engine_type == NAND_ECC_ENGINE_TYPE_ON_HOST) {
oobregion->offset = 2;
- oobregion->length = 2;
+ oobregion->length = USER_DATA_SZ - 2;
return 0;
}
next prev parent reply other threads:[~2026-03-17 14:25 UTC|newest]
Thread overview: 13+ messages / expand[flat|nested] mbox.gz Atom feed top
2026-03-17 14:24 [PATCH v3 0/9] mtd: rawnand: sunxi: Fixes user data length for H6 Richard Genoud
2026-03-17 14:24 ` Richard Genoud [this message]
2026-03-18 7:15 ` [PATCH v3 1/9] mtd: rawnand: sunxi: sunxi_nand_ooblayout_free code clarification Richard GENOUD
2026-03-17 14:24 ` [PATCH v3 2/9] mtd: rawnand: sunxi: fix sunxi_nfc_hw_ecc_read_extra_oob Richard Genoud
2026-03-17 14:24 ` [PATCH v3 3/9] mtd: rawnand: sunxi: do not count BBM bytes twice Richard Genoud
2026-03-17 14:24 ` [PATCH v3 4/9] mtd: rawnand: sunxi: replace hard coded value by a define - take2 Richard Genoud
2026-03-17 14:24 ` [PATCH v3 5/9] mtd: rawnand: sunxi: make the code more self-explanatory Richard Genoud
2026-03-17 14:24 ` [PATCH v3 6/9] mtd: rawnand: sunxi: remove dead code Richard Genoud
2026-03-17 14:34 ` Miquel Raynal
2026-03-17 14:24 ` [PATCH v3 7/9] mtd: rawnand: sunxi: change error prone variable name Richard Genoud
2026-03-17 14:24 ` [PATCH v3 8/9] mtd: rawnand: sunxi: fix typos in comments Richard Genoud
2026-03-17 14:24 ` [PATCH v3 9/9] mtd: rawnand: sunxi: introduce maximize variable user data length Richard Genoud
2026-03-25 14:29 ` [PATCH v3 0/9] mtd: rawnand: sunxi: Fixes user data length for H6 Miquel Raynal
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20260317142437.580204-2-richard.genoud@bootlin.com \
--to=richard.genoud@bootlin.com \
--cc=bbrezillon@kernel.org \
--cc=jernej.skrabec@gmail.com \
--cc=linux-arm-kernel@lists.infradead.org \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-mtd@lists.infradead.org \
--cc=linux-sunxi@lists.linux.dev \
--cc=miquel.raynal@bootlin.com \
--cc=mripard@kernel.org \
--cc=richard@nod.at \
--cc=samuel@sholland.org \
--cc=thomas.petazzoni@bootlin.com \
--cc=vigneshr@ti.com \
--cc=vulab@iscas.ac.cn \
--cc=wens@csie.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -1755,12 +1755,12 @@ static int sunxi_nand_ooblayout_free(struct mtd_info *mtd, int section,
/*
* The first 2 bytes are used for BB markers, hence we
- * only have 2 bytes available in the first user data
+ * only have USER_DATA_SZ - 2 bytes available in the first user data
* section.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox